import { Lexer, Operator, TokenType } from './lexer';
export type ExpressionNode = {
    FunctionCall: {
        name: string;
        args: ExpressionNode[];
    };
} | {
    Identifier: string;
} | {
    Literal: {
        type: TokenType.String | TokenType.Number;
        value: string;
    };
} | {
    Template: {
        parts: ExpressionNode[];
    };
} | {
    Unary: {
        operator: Operator;
        expression: ExpressionNode;
    };
} | {
    Binary: {
        operator: Operator;
        left: ExpressionNode;
        right: ExpressionNode;
    };
};
/**
 * Parses an expression.
 *
 * TODO: Operator precedence is not handled correctly. Use parentheses to be explicit about your desired
 * precedence.
 */
export declare class Parser {
    protected lexer: Lexer;
    parse(expressionString: string): ExpressionNode;
    private parseArgumentList;
    private parseFunctionCall;
    private parseTemplateParts;
    protected parseTemplate(): ExpressionNode;
    private parsePrimary;
    private parseUnary;
    private parseMultiplicative;
    private parseAdditive;
    private parseExpression;
}
/** Parses a template. */
export declare class TemplateParser extends Parser {
    parse(templateString: string): ExpressionNode;
}
